/*---------------------------------------------------------------------------
  
  File		:	braiten.c
  Description   :       Braitenberg vehicle written in C and equivalent to
                        the demo in ROM (written in assembler)
  Author	:	F. Mondada
  History	:	23/10/95	Creation
			03/08/00	Modified by J.Blynel

  ---------------------------------------------------------------------------*/

#include "k_talkMacOSX.c"

char message[K_MSG_SIZE];
char result[K_MSG_SIZE];

#define FORWARD_SPEED 15        

// interconnection matrix between IR proximity sensors and motors
int Interconn[16] = {4,4,6,-18,-15,-5,5,3, -5,-15,-18,6,4,4,3,5};   
int IR[8];

void braiten()
{
  int i, left_speed, right_speed;

  printf("Braitenberg!\n");

  while(1) {

    // Sensor activations
    
    k_talk("N\n", result, K_MSG_SIZE);
    sscanf(result,"n,%i,%i,%i,%i,%i,%i,%i,%i", &IR[0],&IR[1],&IR[2],&IR[3],
           &IR[4],&IR[5],&IR[6],&IR[7]);
    

    // Connections sensors-motors

    left_speed  = 0;
    right_speed = 0;

    for(i=0; i<8; i++) {
      left_speed += IR[i] * Interconn[i];
      right_speed  += IR[i] * Interconn[8+i];
    }

    
    // Global gain

    left_speed  /= 800;                     
    right_speed /= 800;


    // Offset (basic speed)

    left_speed  += FORWARD_SPEED;
    right_speed += FORWARD_SPEED;


    // Set motor speeds

    sprintf(message,"D,%i,%i\n", left_speed, right_speed);
    k_talk(message, result, K_MSG_SIZE);
    
    msleep(100);
  }
}


int main()
{
  k_init();
  braiten();
  k_close();

  return 0;
}


















