/*---------------------------------------------------------------------------
  
  File		:	k_talkMacOSX.h
  Project	:	k_talk
  Description	:	Basic Package for communicating with a Khepera or Koala 
			through the serial line for MacOSX with KeySpan USA28X
                        USB-serial adaptor
                   
  Author	:	D. Floreano <dario.floreano@epfl.ch>
			modified from khep_talk (M. von Holzen, L. Tettoni)
  History	:	21/10/02	Created

  ---------------------------------------------------------------------------*/

#ifndef __K_TALK_H__
#define __K_TALK_H__

#include <stdio.h>
#include <unistd.h>
#include <ctype.h>
#include <fcntl.h>
#include <stdlib.h>
#include <termios.h>
#include <errno.h>
#include <string.h>
#include "types.h"

#define kMyErrReturn            -1
static struct termios sOriginalTTYAttrs;

#define K_MSG_SIZE		512
#define	K_DEFAULT_BAUD		38400
#define	K_DEFAULT_TIMEOUT	5
#define	K_NB_RETRY		3
#define K_DEFAULT_DEV		"/dev/tty.USA28X1213P1.1"

/*---------------------------------------------------------------------------

  Management of the serial line

  ---------------------------------------------------------------------------*/

#define clear(var, mask)                  var &= (~(mask))
#define set(var, mask)                    var |= (mask)
#define let(var, mask)
#define unused(var, mask)
#define	serial_close(fd)                  close(fd)
#define	serial_read(fd, buffer, size)     read(fd, buffer, size)
#define	serial_write(fd, buffer, size)    write(fd, buffer, size)

/*---------------------------------------------------------------------------

  K package routines                                            

  ---------------------------------------------------------------------------*/

extern bool     k_init();
extern bool	k_talk(char *message, char *result, int size);
extern void     k_close();

#endif // __K_TALK_H__

